==> kubernetes-model-kustomize-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/HelmChartArgsFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface HelmChartArgsFluent<A extends HelmChartArgsFluent<A>> extends Fluent<A>{
  public String getChartHome();
  public A withChartHome(String chartHome);
  public Boolean hasChartHome();
  public String getChartName();
  public A withChartName(String chartName);
  public Boolean hasChartName();
  public String getChartRepoName();
  public A withChartRepoName(String chartRepoName);
  public Boolean hasChartRepoName();
  public String getChartRepoUrl();
  public A withChartRepoUrl(String chartRepoUrl);
  public Boolean hasChartRepoUrl();
  public String getChartVersion();
  public A withChartVersion(String chartVersion);
  public Boolean hasChartVersion();
  public A addToExtraArgs(Integer index,String item);
  public A setToExtraArgs(Integer index,String item);
  public A addToExtraArgs(java.lang.String... items);
  public A addAllToExtraArgs(Collection<String> items);
  public A removeFromExtraArgs(java.lang.String... items);
  public A removeAllFromExtraArgs(Collection<String> items);
  public List<String> getExtraArgs();
  public String getExtraArg(Integer index);
  public String getFirstExtraArg();
  public String getLastExtraArg();
  public String getMatchingExtraArg(Predicate<String> predicate);
  public Boolean hasMatchingExtraArg(Predicate<String> predicate);
  public A withExtraArgs(List<String> extraArgs);
  public A withExtraArgs(java.lang.String... extraArgs);
  public Boolean hasExtraArgs();
  public String getHelmBin();
  public A withHelmBin(String helmBin);
  public Boolean hasHelmBin();
  public String getHelmHome();
  public A withHelmHome(String helmHome);
  public Boolean hasHelmHome();
  public String getReleaseName();
  public A withReleaseName(String releaseName);
  public Boolean hasReleaseName();
  public String getReleaseNamespace();
  public A withReleaseNamespace(String releaseNamespace);
  public Boolean hasReleaseNamespace();
  public String getValues();
  public A withValues(String values);
  public Boolean hasValues();
  public A addToValuesLocal(String key,Object value);
  public A addToValuesLocal(Map<String,Object> map);
  public A removeFromValuesLocal(String key);
  public A removeFromValuesLocal(Map<String,Object> map);
  public Map<String,Object> getValuesLocal();
  public <K,V>A withValuesLocal(Map<String,Object> valuesLocal);
  public Boolean hasValuesLocal();
  public String getValuesMerge();
  public A withValuesMerge(String valuesMerge);
  public Boolean hasValuesMerge();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> kubernetes-model-kustomize-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/HelmChartArgsFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HelmChartArgsFluent<A extends HelmChartArgsFluent<A>> extends Fluent<A>{
  public String getChartHome();
  public A withChartHome(String chartHome);
  public Boolean hasChartHome();
  public String getChartName();
  public A withChartName(String chartName);
  public Boolean hasChartName();
  public String getChartRepoName();
  public A withChartRepoName(String chartRepoName);
  public Boolean hasChartRepoName();
  public String getChartRepoUrl();
  public A withChartRepoUrl(String chartRepoUrl);
  public Boolean hasChartRepoUrl();
  public String getChartVersion();
  public A withChartVersion(String chartVersion);
  public Boolean hasChartVersion();
  public A addToExtraArgs(int index,String item);
  public A setToExtraArgs(int index,String item);
  public A addToExtraArgs(java.lang.String... items);
  public A addAllToExtraArgs(Collection<String> items);
  public A removeFromExtraArgs(java.lang.String... items);
  public A removeAllFromExtraArgs(Collection<String> items);
  public List<String> getExtraArgs();
  public String getExtraArg(int index);
  public String getFirstExtraArg();
  public String getLastExtraArg();
  public String getMatchingExtraArg(Predicate<String> predicate);
  public Boolean hasMatchingExtraArg(Predicate<String> predicate);
  public A withExtraArgs(List<String> extraArgs);
  public A withExtraArgs(java.lang.String... extraArgs);
  public Boolean hasExtraArgs();
  public String getHelmBin();
  public A withHelmBin(String helmBin);
  public Boolean hasHelmBin();
  public String getHelmHome();
  public A withHelmHome(String helmHome);
  public Boolean hasHelmHome();
  public String getReleaseName();
  public A withReleaseName(String releaseName);
  public Boolean hasReleaseName();
  public String getReleaseNamespace();
  public A withReleaseNamespace(String releaseNamespace);
  public Boolean hasReleaseNamespace();
  public String getValues();
  public A withValues(String values);
  public Boolean hasValues();
  public A addToValuesLocal(String key,Object value);
  public A addToValuesLocal(Map<String,Object> map);
  public A removeFromValuesLocal(String key);
  public A removeFromValuesLocal(Map<String,Object> map);
  public Map<String,Object> getValuesLocal();
  public <K,V>A withValuesLocal(Map<String,Object> valuesLocal);
  public Boolean hasValuesLocal();
  public String getValuesMerge();
  public A withValuesMerge(String valuesMerge);
  public Boolean hasValuesMerge();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
